@@ -9,7 +9,7 @@ function(mast, v.set, dir.set, num.sectors=12, bins=c(5,10,15,20), digits=3, pri
 	if(missing(v.set) && !missing(dir.set)) v.set <- dir.set
 	
 	if(!is.numeric(num.sectors)) stop("'num.sectors' must be numeric\n")
-	if(num.sectors%%4!=0 || num.sectors<4 | num.sectors>16) stop("Inapplicable number of sectors - choose 4, 8, 12 or 16\n")
+	if(num.sectors<=1) stop("There must be at least 2 sectors\n")
 	if(!is.numeric(v.set)) stop("'v.set' must be numeric\n")
 	if(v.set<=0 || v.set>num.sets) stop("'v.set' not found\n")
 	if(!is.numeric(dir.set)) stop("'dir.set' must be numeric\n")
@@ -63,6 +63,7 @@ function(mast, v.set, dir.set, num.sectors=12, bins=c(5,10,15,20), digits=3, pri
 	
 	if(!is.null(bins)) for(i in 3:(num.classes+2)) freq.tbl[num.sectors+1,i] <- sum(freq.tbl[1:num.sectors,i], na.rm=TRUE)
 	
+	r.names <- c(paste("s", 1:num.sectors, sep=""),"all")
 	if(num.sectors==4) r.names <- c("n","e","s","w","all")
 	if(num.sectors==8) r.names <- c("n","ne","e","se","s","sw","w","nw","all")
 	if(num.sectors==12) r.names <- c("n","nne","ene","e","ese","sse","s","ssw","wsw","w","wnw","nnw","all")
