@@ -9,7 +9,7 @@ function(mast, v.set, dir.set, num.sectors=12, digits=3, print=TRUE) {
 	if(missing(v.set) && !missing(dir.set)) v.set <- dir.set
 	
 	if(!is.numeric(num.sectors)) stop("'num.sectors' must be numeric\n")
-	if(num.sectors%%4!=0 || num.sectors<4 || num.sectors>16) stop("Inapplicable number of sectors - choose 4, 8, 12 or 16\n")
+	if(num.sectors<=1) stop("There must be at least 2 sectors\n")
 	if(!is.numeric(v.set)) stop("'v.set' must be numeric\n")
 	if(v.set<=0 || v.set>num.sets) stop("'v.set' not found\n")
 	if(!is.numeric(dir.set)) stop("'dir.set' must be numeric\n")
@@ -36,10 +36,11 @@ function(mast, v.set, dir.set, num.sectors=12, digits=3, print=TRUE) {
 	weibull.tbl[num.sectors+1,1] <- weibull.param$A
 	weibull.tbl[num.sectors+1,2] <- weibull.param$k
 	
-	freq <- frequency(mast, v.set, dir.set, num.sectors, bins=NULL, digits=digits)
+	freq <- frequency(mast, v.set, dir.set, num.sectors, bins=NULL, digits=digits, print=FALSE)
 	weibull.tbl[,3] <- freq$wind.speed
 	weibull.tbl[,4] <- freq$total
 
+	r.names <- c(paste("s", 1:num.sectors, sep=""),"all")
 	if(num.sectors==4) r.names <- c("n","e","s","w","all")
 	if(num.sectors==8) r.names <- c("n","ne","e","se","s","sw","w","nw","all")
 	if(num.sectors==12) r.names <- c("n","nne","ene","e","ese","sse","s","ssw","wsw","w","wnw","nnw","all")
